==> wt_resource_tool-0.1.0.tar.gz: wt_resource_tool-0.1.0/README.md <==
# WT Resource Tool

> [!warning]
> This project is still in development, PRs are welcome!

As a War Thunder community developer, interested in unpacking data but turned off by the complexity of the results? Try the WT Resource Tool!

We did the hard work for you, parsing the data and making it human-readable, so you can focus on what you do best: creating awesome projects for the War Thunder community.

## Not official

This project is not affiliated with Gaijin Entertainment.

> However, we did get in touch with Gaijin, maybe some interesting things will happen in the future. WHO KNOWS?

## Features

- **Easy to use**: Install `wt-resource-tool` via pip and start using it right away.
- **Human-readable**: All data is parsed and presented in a human-readable format.
- **Accessible**: Don't need to download entire data to your local environment everytime.
- **Up-to-date**: We keep the data up-to-date with the [War-Thunder-Datamine](https://github.com/gszabi99/War-Thunder-Datamine) repository. Thanks to the contributors!

## Data

- **Player titles**: All player titles in the game, including their localization.
- **Player medals**: All player medals in the game, including their localization and image at different sizes.
- **Vehicle data**: All vehicle data in the game

> [!note]
> More data will be added soon!

## Usage

### Use python package `wt-resource-tool`

Install the package using pip:

> [!warning]
> This package is not available on PyPi yet. You can install it from source.

Then you can use it in your python code. We provide some examples to get you started, take a look at the [playground](playground) folder.

### Use static data in json format

You can find data we parsed ahead in json format under `/static` folder.

## Credits

Special thanks to [War-Thunder-Datamine](https://github.com/gszabi99/War-Thunder-Datamine) for providing the original data!

==> wt_resource_tool-0.2.0.tar.gz: wt_resource_tool-0.2.0/README.md <==
# WT Resource Tool

> [!warning]
> This project is still in development, PRs are welcome!

As a War Thunder community developer, interested in unpacking data but turned off by the complexity of the results? Try the WT Resource Tool!

We did the hard work for you, parsing the data and making it human-readable, so you can focus on what you do best: creating awesome projects for the War Thunder community.

## Not affiliated with Gaijin Entertainment

This project is not affiliated with Gaijin Entertainment.

> However, we did get in touch with Gaijin, maybe some interesting things will happen in the future. WHO KNOWS?

## Features

- **Easy to use**: Install `wt-resource-tool` via pip and start using it right away.
- **Human-readable**: All data is parsed and presented in a human-readable format.
- **Accessible**: We provide easy-to-use api to access the data.
- **Up-to-date**: We keep the data up-to-date with the [War-Thunder-Datamine](https://github.com/gszabi99/War-Thunder-Datamine) repository. Thanks to the contributors!

## Data

- **Player titles**: All player titles in the game, including their localization.
- **Player medals**: All player medals in the game, including their localization and image at different sizes.
- **Vehicle data**: All vehicle data in the game

> [!note]
> More data will be added!

## Usage

### Use python package `wt-resource-tool`

Install the package using pip:

```bash
% pip install wt-resource-tool
```

Then you can use it in your python code. We provide some examples to get you started, take a look at the [playground](playground) folder.

## Credits

Special thanks to [War-Thunder-Datamine](https://github.com/gszabi99/War-Thunder-Datamine) for providing the original data!
